/* $Id: aocolor_widget.cpp 29 2009-01-02 13:36:32Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
	Copyright (C) 2005 - 2009  Mawerick

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "aocolor_widget.h"
#include "aocolors.h"
#include "aocrayon.h"

#include <QtGui>

AOColorWidget::AOColorWidget( QWidget *parent )
		: QWidget( parent )
{
	init();
}

AOColorWidget::AOColorWidget( const QString &text, QWidget *parent )
{
	init();
	setText( text );
}

void AOColorWidget::init()
{
	Layout = new QHBoxLayout( this );
	Layout->setSpacing( 3 );
	Layout->setMargin( 0 );

	Label = new QLabel( this );
	Label->setFrameStyle( QFrame::Panel | QFrame::Sunken );
	Label->setIndent( 5 );
	Label->setAutoFillBackground( true );
	Layout->addWidget( Label );

	QFont f( "Tahoma", 10, QFont::Black );
	Label->setFont( f );

	Button = new QPushButton( this );
	Button->setFixedSize( 120, 25 );
	Button->setIconSize( QSize( 60, 15 ) );
	Button->setAutoDefault( false );
	connect( Button, SIGNAL( clicked() ), this, SLOT( pickColor() ) );
	Layout->addWidget( Button );
}

void AOColorWidget::setText( const QString &text )
{
	Label->setText( "<b>" + text + " :</b>" );
}

void AOColorWidget::setBGColor( const QColor &color )
{
	QPalette pal = Label->palette();
	pal.setColor( QPalette::Background, color );
	Label->setPalette( pal );

	pal = Button->palette();
	pal.setColor( QPalette::Button, color );
	Button->setPalette( pal );
}

void AOColorWidget::setToolTip( const QString &text )
{
	Label->setToolTip( text );
	Button->setToolTip( text );
}

void AOColorWidget::clear()
{
	ColorGroups.clear();
}

void AOColorWidget::addColorGroup( const QString &cg )
{
	ColorGroups.append( cg );
}

void AOColorWidget::removeColorGroup( const QString &cg )
{
	ColorGroups.removeAll( cg );
}

void AOColorWidget::updateColor()
{
	if( ColorGroups.size() <= 0 )
		return;

	QString cg = ColorGroups.at( 0 );
	AOColor color = Colors.getByName( cg );
	QPixmap temp( 60, 15 );
	temp.fill( color.color() );
	Button->setIcon( temp );
	QPalette pal = Label->palette();
	pal.setColor( QPalette::WindowText, color.color() );
	Label->setPalette( pal );
}

void AOColorWidget::pickColor()
{
	if( ColorGroups.size() <= 0 )
		return;

	qDebug( "AOColorWidget::pickColor(): list has %d members", ColorGroups.size() );

	AOColor color = Colors.getByName( ColorGroups.at( 0 ) );
	QColor newColor = QColorDialog::getColor( color.color(), this );
	if( !newColor.isValid() )
		return;

	for( int n = 0; n < ColorGroups.size(); n++ )
	{
		color = Colors.getByName( ColorGroups.at( n ) );
		color.setColor( newColor );
		Colors.updateColor( color );
		qDebug( "AOColorWidget::pickColor(): Color %d is '%s' (%s)",
				n, qPrintable( color.name() ), qPrintable( color.value() ) );
	}

	updateColor();
}
