/* $Id$ */
/* AOCrayon - Chat color management tool for Anarchy Online
	Copyright (C) 2005 - 2009  Mawerick

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "aocrayon.h"
#include "aocolors.h"
#include "settings.h"
#include <QtGui>
#include <QtXml>

AOColors Colors;

AOColors::AOColors()
{
}

AOColor AOColors::getByName( const QString &name )
{
	for( AOColors::iterator it = begin(); it != end(); it++ )
	{
		if( (*it).name() == name )
		{
			return (*it);
		}
	}
	return AOColor();
}

bool AOColors::updateColor( const AOColor &color )
{
	for( int n = 0; n < size(); ++n )
	{
		if( at( n ).name() == color.name() )
		{
			replace( n, color );
			return true;
		}
	}
	return false;
}

void AOColors::addColor( const AOColor &color )
{
	append( color );
}

bool AOColors::load()
{
	QDomDocument xmlDoc;
	clear();

	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return false;

	QFile XmlFile( dir->filePath( "TextColors.xml" ) );
	qDebug( "AOColors::load(): file: %s", qPrintable( XmlFile.fileName() ) );

	if( !XmlFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
		return false;

	if( !xmlDoc.setContent( &XmlFile ) )
		return false;

	QDomNodeList nodeList = xmlDoc.elementsByTagName( "HTMLColor" );
	for( int i = 0; i < (int) nodeList.count(); i++ )
	{
		AOColor color;
		QDomNode node = nodeList.item( i );
		QDomElement element = node.toElement();
		color.setValue( element.attribute( "color" ) );
		color.setName( element.attribute( "name" ) );
		append( color );
	}
	XmlFile.close();

	return true;
}

bool AOColors::save()
{
	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return false;

	QFile XmlFile( dir->filePath( "TextColors.xml" ) );
	dir->remove( "TextColors.bak" );
	dir->rename( "TextColors.xml", "TextColors.bak" );
	if( !XmlFile.open( QIODevice::WriteOnly | QIODevice::Text ) )
		return false;

	QDomDocument doc( "" );
	QDomElement root = doc.createElement( "Root" );
	doc.appendChild( root );
	for( AOColors::iterator it = Colors.begin(); it != Colors.end(); it++ )
	{
		QDomElement tag = doc.createElement( "HTMLColor" );
		tag.setAttribute( "color", (*it).value() );
		tag.setAttribute( "name", (*it).name() );
		root.appendChild( tag );
	}

	QString xml = doc.toString( 4 );
	QTextStream stream( &XmlFile );
	stream << "<?xml version=\"1.0\" ?>\n";
	stream << xml;
	XmlFile.close();

	return true;
}
