/* $Id: basicmode_page.cpp 29 2009-01-02 13:36:32Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
	Copyright (C) 2005 - 2009  Mawerick

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "basicmode_page.h"
#include "aocrayon.h"
#include "aocolor_widget.h"

#include <QtGui>

BasicModePage::BasicModePage( QWidget *parent )
		:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 5 );

	TabWidget = new QTabWidget( this );
	BaseLayout->addWidget( TabWidget );

	createChatPage();
	createMoreChatPage();
	createInfoPage();
	createNPCPage();
	createCombatPage();
	createMiscPage();

	TabWidget->addTab( ChatPage, tr( "Chat" ) );
	TabWidget->addTab( MoreChatPage, tr( "Chat (2)" ) );
	TabWidget->addTab( InfoPage, tr( "Info Box" ) );
	TabWidget->addTab( NPCPage, tr( "NPC Chat" ) );
	TabWidget->addTab( CombatPage, tr( "Combat" ) );
	TabWidget->addTab( MiscPage, tr( "Misc." ) );

	/*
		 * Add spacer and help text
		 */
	BaseLayout->addStretch( 1 );

	BasicHelpLabel = new QLabel( this );
	BasicHelpLabel->setMargin( 5 );
	BasicHelpLabel->setText( tr(
			"<strong><u>Changing your chat colors:</u></strong><br />"
			"- Change the colors you want.<br />"
			"- Click <strong><font color='navy'>Save</font></strong> to save the data.<br />"
			"- Launch Anarchy Online.<hr />"
			"<u>If you already have AO running, do this to see your changes:</u><br />"
			"- Press <strong><font color='navy'>CTRL + SHIFT + F7</font></strong>.<br />"
			"- Make the <strong><font color='navy'>Actions</font></strong> tab active by clicking on it.<br />"
			"- Click <strong><font color='navy'>Reload menus</font></strong>."
			) );
	BaseLayout->addWidget( BasicHelpLabel );
}

/*
 * Basic Chat page
 */
void BasicModePage::createChatPage()
{
	ChatPage = new QWidget;
	ChatLayout = new QVBoxLayout( ChatPage );
	ChatLayout->setSpacing( 3 );
	ChatLayout->setMargin( 4 );

	ClanBtn = new AOColorWidget( tr( "Org. chat" ), ChatPage );
	ClanBtn->addColorGroup( "ctch_clan" );
	ClanBtn->addColorGroup( "CCClanColor" );
	connect( this, SIGNAL( updateColor() ), ClanBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), ClanBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( ClanBtn );

	RaidBtn = new AOColorWidget( tr( "Raid channel" ), ChatPage );
	RaidBtn->addColorGroup( "ctch_raid" );
	connect( this, SIGNAL( updateColor() ), RaidBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), RaidBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( RaidBtn );

	PGroupBtn = new AOColorWidget( tr( "Private groups" ), ChatPage );
	PGroupBtn->addColorGroup( "ctch_pgroup" );
	connect( this, SIGNAL( updateColor() ), PGroupBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), PGroupBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( PGroupBtn );

	TeamBtn = new AOColorWidget( tr( "Team chat" ), ChatPage );
	TeamBtn->addColorGroup( "ctch_team" );
	TeamBtn->addColorGroup( "CCTeamColor" );
	connect( this, SIGNAL( updateColor() ), TeamBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), TeamBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( TeamBtn );

	TellBtn = new AOColorWidget( tr( "Private tells" ), ChatPage );
	TellBtn->addColorGroup( "ct_itell" );
	TellBtn->addColorGroup( "ctch_tell" );
	TellBtn->addColorGroup( "CCTellColor" );
	connect( this, SIGNAL( updateColor() ), TellBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), TellBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( TellBtn );

	OOCBtn = new AOColorWidget( tr( "OOC" ), ChatPage );
	OOCBtn->addColorGroup( "ctch_newbie" );
	OOCBtn->addColorGroup( "CCNewbieColor" );
	connect( this, SIGNAL( updateColor() ), OOCBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), OOCBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( OOCBtn );

	MiscBtn = new AOColorWidget( tr( "Misc" ) + " *", ChatPage );
	MiscBtn->setToolTip( "This is used various places, among others Org Leaders chat, and Social chat on TestLive" );
	MiscBtn->addColorGroup( "ctch_misc" );
	MiscBtn->addColorGroup( "CCMiscColor" );
	connect( this, SIGNAL( updateColor() ), MiscBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MiscBtn, SLOT( setBGColor(const QColor&) ) );
	ChatLayout->addWidget( MiscBtn );

	ChatLayout->addStretch( 1 );
}

/*
 * Basic Chat page (cont.)
 */
void BasicModePage::createMoreChatPage()
{
	MoreChatPage = new QWidget;
	MoreChatLayout = new QVBoxLayout( MoreChatPage );
	MoreChatLayout->setSpacing( 3 );
	MoreChatLayout->setMargin( 4 );

	VicinityBtn = new AOColorWidget( tr( "Vicinity" ), MoreChatPage );
	VicinityBtn->addColorGroup( "ctch_vicinity" );
	VicinityBtn->addColorGroup( "CCVicinityColor" );
	connect( this, SIGNAL( updateColor() ), VicinityBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), VicinityBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( VicinityBtn );

	WhisperBtn = new AOColorWidget( tr( "Whispers" ), MoreChatPage );
	WhisperBtn->addColorGroup( "ctch_whisper" );
	WhisperBtn->addColorGroup( "CCWhisperColor" );
	connect( this, SIGNAL( updateColor() ), WhisperBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), WhisperBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( WhisperBtn );

	ShoutBtn = new AOColorWidget( tr( "Shouts" ), MoreChatPage );
	ShoutBtn->addColorGroup( "ctch_shout" );
	ShoutBtn->addColorGroup( "CCShoutColor" );
	connect( this, SIGNAL( updateColor() ), ShoutBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), ShoutBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( ShoutBtn );

	EmotesBtn = new AOColorWidget( tr( "Emotes" ), MoreChatPage );
	EmotesBtn->addColorGroup( "ctch_emote" );
	EmotesBtn->addColorGroup( "CCEmoteColor" );
	connect( this, SIGNAL( updateColor() ), EmotesBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), EmotesBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( EmotesBtn );

	/** NOTE:
		 * Yes, shopping channels use the "seeking team" chat groups.
		 * It's actually the only channel using that group after FC
		 * removed the seeking team channels.
		 */
	ShoppingBtn = new AOColorWidget( tr( "Shopping channels" ), MoreChatPage );
	ShoppingBtn->addColorGroup( "ctch_seekingteam" );
	ShoppingBtn->addColorGroup( "CCSeekingTeamColor" );
	connect( this, SIGNAL( updateColor() ), ShoppingBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), ShoppingBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( ShoppingBtn );

	MyPetBtn = new AOColorWidget( tr( "My pet" ), MoreChatPage );
	MyPetBtn->addColorGroup( "ctch_mypet" );
	connect( this, SIGNAL( updateColor() ), MyPetBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MyPetBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( MyPetBtn );

	OtherPetBtn = new AOColorWidget( tr( "n00bs pet" ), MoreChatPage );
	OtherPetBtn->addColorGroup( "ctch_otherpet" );
	connect( this, SIGNAL( updateColor() ), OtherPetBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), OtherPetBtn, SLOT( setBGColor(const QColor&) ) );
	MoreChatLayout->addWidget( OtherPetBtn );

	MoreChatLayout->addStretch( 1 );
}

/*
 * Info window page
 */
void BasicModePage::createInfoPage()
{
	InfoPage = new QWidget;
	InfoLayout = new QVBoxLayout( InfoPage );
	InfoLayout->setSpacing( 3 );
	InfoLayout->setMargin( 4 );

	HeadlineBtn = new AOColorWidget( tr( "Headline" ), InfoPage );
	HeadlineBtn->addColorGroup( "CCInfoHeadline" );
	connect( this, SIGNAL( updateColor() ), HeadlineBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), HeadlineBtn, SLOT( setBGColor(const QColor&) ) );
	InfoLayout->addWidget( HeadlineBtn );

	HeaderBtn = new AOColorWidget( tr( "Header" ), InfoPage );
	HeaderBtn->addColorGroup( "CCInfoHeader" );
	connect( this, SIGNAL( updateColor() ), HeaderBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), HeaderBtn, SLOT( setBGColor(const QColor&) ) );
	InfoLayout->addWidget( HeaderBtn );

	TextBtn = new AOColorWidget( tr( "Normal text" ), InfoPage );
	TextBtn->addColorGroup( "CCInfoText" );
	connect( this, SIGNAL( updateColor() ), TextBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), TextBtn, SLOT( setBGColor(const QColor&) ) );
	InfoLayout->addWidget( TextBtn );

	BoldBtn = new AOColorWidget( tr( "Bold text" ), InfoPage );
	BoldBtn->addColorGroup( "CCInfoTextBold" );
	connect( this, SIGNAL( updateColor() ), BoldBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), BoldBtn, SLOT( setBGColor(const QColor&) ) );
	InfoLayout->addWidget( BoldBtn );

	InfoLayout->addStretch( 1 );
}

/*
 * NPC Chat page
 */
void BasicModePage::createNPCPage()
{
	NPCPage = new QWidget;
	NPCLayout = new QVBoxLayout( NPCPage );
	NPCLayout->setSpacing( 3 );
	NPCLayout->setMargin( 4 );

	NPCChatBtn = new AOColorWidget( tr( "NPC chat text" ), NPCPage );
	NPCChatBtn->addColorGroup( "CCNPCChatText" );
	connect( this, SIGNAL( updateColor() ), NPCChatBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCChatBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCChatBtn );

	NPCOOCBtn = new AOColorWidget( tr( "NPC OOC text" ), NPCPage );
	NPCOOCBtn->addColorGroup( "CCNPCOOCText" );
	connect( this, SIGNAL( updateColor() ), NPCOOCBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCOOCBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCOOCBtn );

	NPCEmoteBtn = new AOColorWidget( tr( "NPC emotes" ), NPCPage );
	NPCEmoteBtn->addColorGroup( "CCNPCChatEmote" );
	connect( this, SIGNAL( updateColor() ), NPCEmoteBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCEmoteBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCEmoteBtn );

	NPCSystemBtn = new AOColorWidget( tr( "NPC system text" ), NPCPage );
	NPCSystemBtn->addColorGroup( "CCNPCChatSystem" );
	connect( this, SIGNAL( updateColor() ), NPCSystemBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCSystemBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCSystemBtn );

	NPCQuestionBtn = new AOColorWidget( tr( "Your chat" ), NPCPage );
	NPCQuestionBtn->addColorGroup( "CCNPCChatQuestion" );
	connect( this, SIGNAL( updateColor() ), NPCQuestionBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCQuestionBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCQuestionBtn );

	NPCDescriptBtn = new AOColorWidget( tr( "Descriptions" ), NPCPage );
	NPCDescriptBtn->addColorGroup( "CCNPCChatDescription" );
	connect( this, SIGNAL( updateColor() ), NPCDescriptBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCDescriptBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCDescriptBtn );

	NPCTradeBtn = new AOColorWidget( tr( "Trade text" ), NPCPage );
	NPCTradeBtn->addColorGroup( "CCNPCChatTrade" );
	connect( this, SIGNAL( updateColor() ), NPCTradeBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), NPCTradeBtn, SLOT( setBGColor(const QColor&) ) );
	NPCLayout->addWidget( NPCTradeBtn );

	NPCLayout->addStretch( 1 );
}

/*
 * Combat feedback page
 */
void BasicModePage::createCombatPage()
{
	CombatPage = new QWidget;
	CombatLayout = new QVBoxLayout( CombatPage );
	CombatLayout->setSpacing( 3 );
	CombatLayout->setMargin( 4 );

	MeHitByNanoBtn = new AOColorWidget( tr( "You got hit by nano" ), CombatPage );
	MeHitByNanoBtn->addColorGroup( "CCMeHitByNanoColor" );
	connect( this, SIGNAL( updateColor() ), MeHitByNanoBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MeHitByNanoBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( MeHitByNanoBtn );

	OtherHitByNanoBtn = new AOColorWidget( tr( "n00b got hit by nano" ), CombatPage );
	OtherHitByNanoBtn->addColorGroup( "CCOtherHitByNanoColor" );
	connect( this, SIGNAL( updateColor() ), OtherHitByNanoBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), OtherHitByNanoBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( OtherHitByNanoBtn );

	MonsterHitMeBtn = new AOColorWidget( tr( "You got hit by an NPC" ), CombatPage );
	MonsterHitMeBtn->addColorGroup( "CCMonsterHitMeColor" );
	connect( this, SIGNAL( updateColor() ), MonsterHitMeBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MonsterHitMeBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( MonsterHitMeBtn );

	PlayerHitMeBtn = new AOColorWidget( tr( "You got hit by a n00b" ), CombatPage );
	PlayerHitMeBtn->addColorGroup( "CCPlayerHitMeColor" );
	connect( this, SIGNAL( updateColor() ), PlayerHitMeBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), PlayerHitMeBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( PlayerHitMeBtn );

	MeHitOtherBtn = new AOColorWidget( tr( "You hit someone" ), CombatPage );
	MeHitOtherBtn->addColorGroup( "CCMeHitOtherColor" );
	connect( this, SIGNAL( updateColor() ), MeHitOtherBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MeHitOtherBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( MeHitOtherBtn );

	OtherHitOtherBtn = new AOColorWidget( tr( "n00b got hit by another n00b" ), CombatPage );
	OtherHitOtherBtn->addColorGroup( "CCOtherHitOtherColor" );
	connect( this, SIGNAL( updateColor() ), OtherHitOtherBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), OtherHitOtherBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( OtherHitOtherBtn );

	OtherHitByPetBtn = new AOColorWidget( tr( "n00b got hit by your pet" ), CombatPage );
	OtherHitByPetBtn->addColorGroup( "CCOtherHitOtherMyPetColor" );
	connect( this, SIGNAL( updateColor() ), OtherHitByPetBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), OtherHitByPetBtn, SLOT( setBGColor(const QColor&) ) );
	CombatLayout->addWidget( OtherHitByPetBtn );

	CombatLayout->addStretch( 1 );
}

/*
 * Misc. feedback page
 */
void BasicModePage::createMiscPage()
{
	MiscPage = new QWidget;
	MiscLayout = new QVBoxLayout( MiscPage );
	MiscLayout->setSpacing( 3 );
	MiscLayout->setMargin( 4 );

	TowerBtn = new AOColorWidget( tr( "Towers &amp; Org. Msg." ), MiscPage );
	TowerBtn->addColorGroup( "ctch_tower" );
	TowerBtn->addColorGroup( "CCTowerColor" );
	connect( this, SIGNAL( updateColor() ), TowerBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), TowerBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( TowerBtn );

	MeGotXPBtn = new AOColorWidget( tr( "XP/SK feedback" ), MiscPage );
	MeGotXPBtn->addColorGroup( "CCMeGotXpColor" );
	connect( this, SIGNAL( updateColor() ), MeGotXPBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MeGotXPBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( MeGotXPBtn );

	ResearchBtn = new AOColorWidget( tr( "Research feedback" ), MiscPage );
	ResearchBtn->addColorGroup( "ctch_research" );
	connect( this, SIGNAL( updateColor() ), ResearchBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), ResearchBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( ResearchBtn );

	MeHealedBtn = new AOColorWidget( tr( "Healing feedback" ), MiscPage );
	MeHealedBtn->addColorGroup( "CCMeHealedColor" );
	connect( this, SIGNAL( updateColor() ), MeHealedBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), MeHealedBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( MeHealedBtn );

	SkillBtn = new AOColorWidget( tr( "Skill available" ), MiscPage );
	SkillBtn->addColorGroup( "CCSkillColor" );
	connect( this, SIGNAL( updateColor() ), SkillBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), SkillBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( SkillBtn );

	SystemBtn = new AOColorWidget( tr( "System messages" ) + " *", MiscPage );
	SystemBtn->setToolTip( "Various feedback such as \"Casting nanoprogram...\" etc." );
	SystemBtn->addColorGroup( "ct_system" );
	connect( this, SIGNAL( updateColor() ), SystemBtn, SLOT( updateColor() ) );
	connect( this, SIGNAL( updateBGColor(const QColor&) ), SystemBtn, SLOT( setBGColor(const QColor&) ) );
	MiscLayout->addWidget( SystemBtn );

	MiscLayout->addStretch( 1 );
}

void BasicModePage::updateColors()
{
	emit updateColor();
}

void BasicModePage::setBGColor( const QColor &BGColor )
{
	emit updateBGColor( BGColor );
}
