/* $Id: settings_page.cpp 29 2009-01-02 13:36:32Z mawerick $ */
/* AOCrayon - Chat color management tool for Anarchy Online
	Copyright (C) 2005 - 2009  Mawerick

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; version 2 of the License.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "aocrayon.h"
#include "aocolor.h"
#include "settings.h"
#include "settings_page.h"

#include <QtGui>

SettingsPage::SettingsPage( QWidget *parent )
		:QWidget( parent )
{
	BaseLayout = new QVBoxLayout( this );
	BaseLayout->setSpacing( 3 );
	BaseLayout->setMargin( 4 );

	AOPathLayout = new QHBoxLayout;

	AOPathLabel = new QLabel( tr( "AO Install Folder:" ), this );
	AOPathLayout->addWidget( AOPathLabel );

	AOPathBox = new QLineEdit( this );
	connect( AOPathBox, SIGNAL( textChanged(const QString&) ), SLOT( setAOPath(const QString&) ) );
	AOPathLayout->addWidget( AOPathBox );

	AOPathBtn = new QPushButton( "", this );
	AOPathBtn->setIcon( QPixmap( ":/Browse" ) );
	AOPathBtn->setFixedSize( 26, 22 );
	AOPathBtn->setAutoDefault( false );
	connect( AOPathBtn, SIGNAL( clicked() ), SLOT( browseAOPath() ) );
	AOPathLayout->addWidget( AOPathBtn );

	BaseLayout->addLayout( AOPathLayout );

	AOPathErrorLabel = new QLabel( "<font color=red><b>"
								   + tr( "Selected path is not a valid AO installation!" )
								   + "</b></font>", this );
	BaseLayout->addWidget( AOPathErrorLabel );

	GUILayout = new QHBoxLayout;

	GUILabel = new QLabel( tr( "AO GUI:" ), this );
	GUILayout->addWidget( GUILabel );

	GUIList = new QComboBox( this );
	GUIList->setToolTip( tr( "Select the AO GUI you are using." ) );
	connect( GUIList, SIGNAL( activated(const QString &) ), SLOT( setGUI(const QString &) ) );
	GUILayout->addWidget( GUIList );

	BaseLayout->addLayout( GUILayout );

	GUIErrorLabel = new QLabel( "<font color=red><b>"
								+ tr( "Selected path does not contain any valid AO GUIs!" )
								+ "</b></font>", this );
	BaseLayout->addWidget( GUIErrorLabel );

	ReloadBtn = new QPushButton( tr( "Reload Chat color data" ), this );
	ReloadBtn->setAutoDefault( false );
	connect( ReloadBtn, SIGNAL( clicked() ), SLOT( restoreColors() ) );
	BaseLayout->addWidget( ReloadBtn );

	QFrame * Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	RestoreBackupBtn = new QPushButton( tr( "Restore last backup" ), this );
	RestoreBackupBtn->setAutoDefault( false );
	connect( RestoreBackupBtn, SIGNAL( clicked() ), SLOT( restoreBackup() ) );
	BaseLayout->addWidget( RestoreBackupBtn );

	RestoreOriginalBtn = new QPushButton( tr( "Restore original colors" ), this );
	RestoreOriginalBtn->setAutoDefault( false );
	connect( RestoreOriginalBtn, SIGNAL( clicked() ), SLOT( restoreOriginalColors() ) );
	BaseLayout->addWidget( RestoreOriginalBtn );

	RestoreBundledBtn = new QPushButton( tr( "Restore original colors from bundled file" ), this );
	RestoreBundledBtn->setAutoDefault( false );
	connect( RestoreBundledBtn, SIGNAL( clicked() ), SLOT( restoreBundledColors() ) );
	BaseLayout->addWidget( RestoreBundledBtn);

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	StyleLayout = new QHBoxLayout;

	StyleLabel = new QLabel( tr( "GUI Style:" ), this );
	StyleLayout->addWidget( StyleLabel );

	StyleList = new QComboBox( this );
	StyleList->addItems( QStyleFactory::keys() );
	int index = StyleList->findText( Prefs.get( "GUIStyle" ).toString(), Qt::MatchFixedString );
	if( index != -1 )
		StyleList->setCurrentIndex( index );
	StyleList->setToolTip( tr( "Select the Qt style to use for the program." ) );
	connect( StyleList, SIGNAL( activated(const QString &) ), SLOT( setStyle(const QString &) ) );
	StyleLayout->addWidget( StyleList );

	BaseLayout->addLayout( StyleLayout );

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	BGColorLayout = new QHBoxLayout;

	BGColorLabel = new QLabel( tr( "Background color:" ), this );
	BGColorLayout->addWidget( BGColorLabel );

	BGColorBtn = new QPushButton( this );
	BGColorBtn->setIconSize( QSize( 60, 15 ) );
	BGColorBtn->setAutoDefault( false );
	connect( BGColorBtn, SIGNAL( clicked() ), SLOT( pickBGColor() ) );
	BGColorLayout->addWidget( BGColorBtn );

	BaseLayout->addLayout( BGColorLayout );

	Hline = new QFrame( this );
	Hline->setFrameStyle( QFrame::HLine | QFrame::Sunken );
	BaseLayout->addWidget( Hline );

	ModeBtn = new QCheckBox( tr( "Advanced mode" ), this );
	ModeBtn->setChecked( Prefs.get( "AdvancedMode" ).toBool() );
	connect( ModeBtn, SIGNAL( toggled(bool) ), SLOT( setMode(bool) ) );
	BaseLayout->addWidget( ModeBtn );

	BaseLayout->addStretch( 1 );
	setAOPath( Prefs.get( "AOGamePath" ).toString() );
}

bool SettingsPage::browseAOPath()
{
	QString path = Prefs.get( "AOGamePath" ).toString();;
	path = QFileDialog::getExistingDirectory( 0, tr( "Select the folder where Anarchy Online is installed:" ), path );
	if( !path.isEmpty() )
	{
		setAOPath( path );
		return true;
	}
	return false;
}

void SettingsPage::setAOPath( const QString &path )
{
	QString clean = Settings::cleanPath( path );
	Prefs.set( "AOGamePath", clean );
	AOPathBox->setText( clean );
	qDebug( "SettingsPage::setAOPath: %s", qPrintable( clean ) );
	QDir *dir = Prefs.getGuiBaseDir();
	if( dir && dir->exists() )
	{
		AOPathErrorLabel->hide();
		ReloadBtn->show();
	}
	else
	{
		AOPathErrorLabel->show();
		ReloadBtn->hide();
	}
	updateGUIs();
}

void SettingsPage::updateGUIs()
{
	GUIList->clear();
	QString clean = Settings::cleanPath( Prefs.get( "AOGamePath" ).toString() );
	qDebug( "SettingsPage::updateGUIs: %s", qPrintable( clean ) );
	QDir *dir = Prefs.getGuiBaseDir();
	if( dir && dir->exists() )
	{
		QFileInfoList files = dir->entryInfoList( QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name );
		if( files.count() > 1 )
		{
			for( int n = 0; n < files.count(); n++ )
			{
				QFileInfo file = files.at( n );
				GUIList->addItem( file.fileName().trimmed() );
			}
			setGUI( Prefs.get( "GUIName", "Default" ).toString() );
			GUILabel->show();
			GUIList->show();
		}
		else
		{
			setGUI( "Default" );
			GUILabel->hide();
			GUIList->hide();
		}
	}
	else
	{
		GUILabel->hide();
		GUIList->hide();
	}
}

void SettingsPage::setGUI( const QString &gui )
{
	Prefs.set( "GUIName", gui );
	int index = GUIList->findText( Prefs.get( "GUIName", "Default" ).toString(), Qt::MatchFixedString );
	if( index != -1 )
		GUIList->setCurrentIndex( index );

	QDir *dir = Prefs.getGuiDir();
	if( dir && dir->exists() )
	{
		qDebug( "SettingsPage::setGUI: path: %s (GUI: %s)",
				qPrintable( dir->absolutePath() ),
				qPrintable( gui ) );
		GUIErrorLabel->hide();
		ReloadBtn->show();
	}
	else
	{
		GUIErrorLabel->show();
		ReloadBtn->hide();
	}
}

bool SettingsPage::confirmAOPath()
{
	QDir *dir = Prefs.getGuiBaseDir();
	while( !dir || !dir->exists() )
	{
		if( browseAOPath() == false )
			return false;

		dir = Prefs.getGuiBaseDir();
	}
	return true;
}

bool SettingsPage::backupOriginalColors()
{
	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return false;

	if( dir->exists( "TextColors.orig" ) )
	{
		int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
										tr( "File %1 exists. Overwrite?" )
											.arg( "TextColors.orig" ),
										QMessageBox::Yes, QMessageBox::No );
		if( ret == QMessageBox::No )
			return false;
		else
			dir->remove( "TextColors.orig" );
	}

	QFile XmlFile( dir->filePath( "TextColors.xml" ) );
	if( !XmlFile.copy( dir->filePath( "TextColors.orig" ) ) )
		return false;

	return true;
}

void SettingsPage::restoreOriginalColors()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
									tr( "Reload original colors? All changes will be lost." ),
									QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::No )
		return;

	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return;

	QFile BackupFile( dir->filePath( "TextColors.orig" ) );
	dir->remove( "TextColors.xml" );
	BackupFile.copy( dir->filePath( "TextColors.xml" ) );

	emit reloadColors();
}

void SettingsPage::restoreBundledColors()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
									tr( "Reload original colors? All changes will be lost." ),
									QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::No )
		return;

	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return;

	QFile BackupFile( "TextColors.orig" );
	dir->remove( "TextColors.xml" );
	BackupFile.copy( dir->filePath( "TextColors.xml" ) );

	emit reloadColors();
}

void SettingsPage::restoreBackup()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
									tr( "Restore last backup? All changes will be lost." ),
									QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::No )
		return;

	QDir *dir = Prefs.getGuiDir();
	if( !dir || !dir->exists() )
		return;

	QFile BackupFile( dir->filePath( "TextColors.bak" ) );
	dir->remove( "TextColors.xml" );
	BackupFile.copy( dir->filePath( "TextColors.xml"		) );

	emit reloadColors();
}

void SettingsPage::restoreColors()
{
	int ret = QMessageBox::warning( this, PROGRAM " v" VERSION,
									tr( "Reload saved colors? All changes will be lost." ),
									QMessageBox::Yes, QMessageBox::No );
	if( ret == QMessageBox::No )
		return;

	emit reloadColors();
}

void SettingsPage::setMode( bool mode )
{
	Prefs.set( "AdvancedMode", mode );
	emit modeChanged( mode );
}

void SettingsPage::setStyle( const QString &style )
{
	Prefs.set( "GUIStyle", style );
	emit styleChanged( style );
}

void SettingsPage::pickBGColor()
{
	QColor color;
	color.setNamedColor( Prefs.get( "BackgroundColor" ).toString() );
	color = QColorDialog::getColor( color, this );
	if( !color.isValid() )
		return;

	Prefs.set( "BackgroundColor", color.name() );
	emit updateBGColor();
}

void SettingsPage::setBGColor( const QColor &color )
{
	QPixmap temp( 60, 15 );
	temp.fill( color );
	BGColorBtn->setIcon( temp );
}
